@@ -1,9 +1,14 @@
 from numba import int64
-from numba.experimental import jitclass
 
 
-@jitclass
 class LinearAsset:
+    r"""
+    Linear asset: the common type of asset.
+
+    Args:
+        contract_size: Contract size of the asset.
+    """
+
     contract_size: int64
 
     def __init__(self, contract_size=1):
@@ -16,8 +21,14 @@ class LinearAsset:
         return balance + self.contract_size * position * price - fee
 
 
-@jitclass
 class InverseAsset:
+    r"""
+    Inverse asset: the contract's notional value is denominated in the quote currency.
+
+    Args:
+        contract_size: Contract size of the asset.
+    """
+
     contract_size: int64
 
     def __init__(self, contract_size=1):
@@ -28,7 +39,3 @@ class InverseAsset:
 
     def equity(self, price, balance, position, fee):
         return -balance - self.contract_size * position / price - fee
-
-
-Linear = LinearAsset()
-Inverse = InverseAsset()
