@@ -7,9 +7,31 @@ import numpy as np
 
 from .proc import Proc, proc_spec
 from ..marketdepth import INVALID_MAX, INVALID_MIN
-from ..order import BUY, SELL, NEW, CANCELED, FILLED, EXPIRED, PARTIALLY_FILLED, GTX, FOK, IOC, NONE, order_ladder_ty
-from ..reader import COL_EVENT, COL_EXCH_TIMESTAMP, COL_SIDE, COL_PRICE, COL_QTY, DEPTH_CLEAR_EVENT, DEPTH_EVENT, \
-    DEPTH_SNAPSHOT_EVENT, TRADE_EVENT
+from ..order import (
+    BUY,
+    SELL,
+    NEW,
+    CANCELED,
+    FILLED,
+    EXPIRED,
+    PARTIALLY_FILLED,
+    GTX,
+    FOK,
+    IOC,
+    NONE,
+    order_ladder_ty
+)
+from ..reader import (
+    COL_EVENT,
+    COL_EXCH_TIMESTAMP,
+    COL_SIDE,
+    COL_PRICE,
+    COL_QTY,
+    DEPTH_CLEAR_EVENT,
+    DEPTH_EVENT,
+    DEPTH_SNAPSHOT_EVENT,
+    TRADE_EVENT
+)
 
 
 class PartialFillExchange_(Proc):
